Package: gWidgets2
Type: Package
Title: Rewrite of gWidgets API for Simplified GUI Construction
Version: 1.0-10
Authors@R: person("John", "Verzani", email = "jverzani@gmail.com",role = c("aut", "cre"))
URL: https://github.com/gWidgets3/gWidgets2
Description: Re-implementation of the 'gWidgets' API. The API is defined in this
    package. A second, toolkit-specific package is required to use it. At this point only 'gWidgets2tcltk' is viable.
Depends: methods, digest
License: GPL (>= 3)
LazyLoad: yes
Collate: 'misc.R' 'guiToolkit.R' 'BasicInterface.R' 'S4-methods.R'
        'S3-methods.R' 'command-stack.R' 'methods.R' 'dialogs.R'
        'gWidgets2-package.R' 'gaction.R' 'gbutton.R' 'gcalendar.R'
        'gcheckbox.R' 'gcheckboxgroup.R' 'gcombobox.R' 'gdf.R'
        'gdfnotebook.R' 'gedit.R' 'ggroup.R' 'gframe.R'
        'gexpandgroup.R' 'gfile.R' 'gfilter.R' 'gformlayout.R'
        'ggraphics.R' 'ggraphicsnotebook.R' 'ghtml.R' 'gimage.R'
        'glabel.R' 'glayout.R' 'gmenu.R' 'gnotebook.R' 'gpanedgroup.R'
        'gprogressbar.R' 'gradio.R' 'gseparator.R' 'gslider.R'
        'gspinbutton.R' 'gstackwidget.R' 'gstatusbar.R' 'gtable.R'
        'gtext.R' 'gtimer.R' 'gtoolbar.R' 'gtree.R' 'ws-model.R'
        'gvarbrowser.R' 'gwindow.R' 'handler-methods.R' 'icons.R'
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2024-12-07 17:00:58 UTC; jverzani
Author: John Verzani [aut, cre]
Maintainer: John Verzani <jverzani@gmail.com>
Repository: CRAN
Date/Publication: 2024-12-07 19:00:07 UTC
Built: R 4.6.0; ; 2026-04-25 16:35:02 UTC; unix
