# Generated by roxygen2: do not edit by hand

S3method("[",GComponent)
S3method("[",GContainer)
S3method("[",GDefaultWidget)
S3method("[",GDf)
S3method("[",GEdit)
S3method("[",GFilter)
S3method("[",GLayout)
S3method("[",GNotebook)
S3method("[",GTable)
S3method("[",GTree)
S3method("[<-",GCheckbox)
S3method("[<-",GComboBox)
S3method("[<-",GComponent)
S3method("[<-",GLayout)
S3method("[<-",GRadio)
S3method("dimnames<-",GComponent)
S3method("editable<-",default)
S3method("enabled<-",default)
S3method("focus<-",default)
S3method("font<-",GText)
S3method("font<-",default)
S3method("length<-",GComponent)
S3method("names<-",GComponent)
S3method("names<-",GFrame)
S3method("size<-",GTable)
S3method("size<-",default)
S3method("svalue<-",GCheckbox)
S3method("svalue<-",GFormLayout)
S3method("svalue<-",GGroup)
S3method("svalue<-",GHtml)
S3method("svalue<-",GLabel)
S3method("svalue<-",GMenuBar)
S3method("svalue<-",GNotebook)
S3method("svalue<-",GRadio)
S3method("svalue<-",GToolBar)
S3method("svalue<-",GTree)
S3method("svalue<-",default)
S3method("tag<-",default)
S3method("tooltip<-",default)
S3method("visible<-",GDf)
S3method("visible<-",GExpandGroup)
S3method("visible<-",default)
S3method(.gdfnotebook,default)
S3method(.gfilter,default)
S3method(add,GMenuBar)
S3method(add,GNotebook)
S3method(add,GToolBar)
S3method(add,GWindow)
S3method(add,default)
S3method(addDragMotion,default)
S3method(addDropSource,default)
S3method(addDropTarget,default)
S3method(addHandler,default)
S3method(addHandlerBlur,default)
S3method(addHandlerChanged,GButton)
S3method(addHandlerChanged,GCalendar)
S3method(addHandlerChanged,GCheckbox)
S3method(addHandlerChanged,GCheckboxGroup)
S3method(addHandlerChanged,GComboBox)
S3method(addHandlerChanged,GDf)
S3method(addHandlerChanged,GEdit)
S3method(addHandlerChanged,GExpandGroup)
S3method(addHandlerChanged,GNotebook)
S3method(addHandlerChanged,GTable)
S3method(addHandlerChanged,default)
S3method(addHandlerClicked,default)
S3method(addHandlerColumnDoubleclicked,default)
S3method(addHandlerColumnRightclicked,default)
S3method(addHandlerColumnclicked,default)
S3method(addHandlerControlclick,default)
S3method(addHandlerDestroy,default)
S3method(addHandlerDoubleclick,GTable)
S3method(addHandlerDoubleclick,default)
S3method(addHandlerExpose,default)
S3method(addHandlerFocus,default)
S3method(addHandlerKeystroke,default)
S3method(addHandlerMouseMotion,default)
S3method(addHandlerRightclick,default)
S3method(addHandlerSelect,default)
S3method(addHandlerSelectionChanged,default)
S3method(addHandlerShiftclick,default)
S3method(addHandlerUnrealize,default)
S3method(addPopupMenu,default)
S3method(addRightclickPopupMenu,default)
S3method(addSpace,GContainer)
S3method(addSpring,GContainer)
S3method(blockHandler,default)
S3method(blockHandlers,default)
S3method(delete,GContainer)
S3method(dim,GComponent)
S3method(dimnames,GComponent)
S3method(dispose,GBasicDialog)
S3method(dispose,GComponent)
S3method(dispose,GNotebook)
S3method(dispose,GStackWidget)
S3method(dispose,GText)
S3method(dispose,GWindow)
S3method(editable,default)
S3method(enabled,default)
S3method(focus,default)
S3method(font,default)
S3method(getBlock,GComponent)
S3method(getBlock,GWindow)
S3method(getToolkitWidget,default)
S3method(getTopLevel,GComponent)
S3method(getWidget,GComponent)
S3method(insert,GText)
S3method(isExtant,default)
S3method(length,GComponent)
S3method(names,GComponent)
S3method(names,GNotebook)
S3method(redo,GComponent)
S3method(removeHandler,default)
S3method(short_summary,"function")
S3method(short_summary,character)
S3method(short_summary,data.frame)
S3method(short_summary,default)
S3method(short_summary,list)
S3method(short_summary,lm)
S3method(short_summary,logical)
S3method(short_summary,matrix)
S3method(short_summary,numeric)
S3method(size,default)
S3method(str,GComponent)
S3method(svalue,GButton)
S3method(svalue,GCalendar)
S3method(svalue,GCheckboxGroup)
S3method(svalue,GComboBox)
S3method(svalue,GDf)
S3method(svalue,GEdit)
S3method(svalue,GFilter)
S3method(svalue,GFormLayout)
S3method(svalue,GMenuBar)
S3method(svalue,GRadio)
S3method(svalue,GTable)
S3method(svalue,GText)
S3method(svalue,GTree)
S3method(svalue,GVarBrowser)
S3method(svalue,default)
S3method(tag,default)
S3method(tooltip,default)
S3method(unblockHandler,default)
S3method(unblockHandlers,default)
S3method(undo,GComponent)
S3method(update,GComponent)
S3method(update,GTree)
S3method(visible,GBasicDialog)
S3method(visible,GTable)
S3method(visible,default)
export("editable<-")
export("enabled<-")
export("focus<-")
export("font<-")
export("size<-")
export("svalue<-")
export("tag<-")
export("tooltip<-")
export("visible<-")
export(.addStockIcons)
export(.gaction)
export(.galert)
export(.gbasicdialog)
export(.gbutton)
export(.gcalendar)
export(.gcheckbox)
export(.gcheckboxgroup)
export(.gcombobox)
export(.gconfirm)
export(.gdf)
export(.gdfnotebook)
export(.gedit)
export(.getStockIconByName)
export(.getStockIcons)
export(.gexpandgroup)
export(.gfile)
export(.gfilebrowse)
export(.gfilter)
export(.gformlayout)
export(.gframe)
export(.ggraphics)
export(.ggraphicsnotebook)
export(.ggroup)
export(.ghtml)
export(.gimage)
export(.ginput)
export(.glabel)
export(.glayout)
export(.gmenu)
export(.gmessage)
export(.gnotebook)
export(.gpanedgroup)
export(.gprogressbar)
export(.gradio)
export(.gseparator)
export(.gslider)
export(.gspinbutton)
export(.gstackwidget)
export(.gstatusbar)
export(.gtable)
export(.gtext)
export(.gtimer)
export(.gtoolbar)
export(.gtree)
export(.gvarbrowser)
export(.gwindow)
export(.stockIconFromClass)
export(.stockIconFromObject)
export(XXX)
export(add)
export(addDragMotion)
export(addDropSource)
export(addDropTarget)
export(addHandler)
export(addHandlerBlur)
export(addHandlerChanged)
export(addHandlerClicked)
export(addHandlerColumnDoubleclicked)
export(addHandlerColumnRightclicked)
export(addHandlerColumnclicked)
export(addHandlerControlclick)
export(addHandlerDestroy)
export(addHandlerDoubleclick)
export(addHandlerExpose)
export(addHandlerFocus)
export(addHandlerIdle)
export(addHandlerKeystroke)
export(addHandlerMouseMotion)
export(addHandlerRightclick)
export(addHandlerSelect)
export(addHandlerSelectionChanged)
export(addHandlerShiftclick)
export(addHandlerUnrealize)
export(addPopupMenu)
export(addRightclickPopupMenu)
export(addSpace)
export(addSpring)
export(addStockIcons)
export(blockHandler)
export(blockHandlers)
export(delete)
export(dispose)
export(editable)
export(enabled)
export(focus)
export(font)
export(gaction)
export(galert)
export(gbasicdialog)
export(gbutton)
export(gcalendar)
export(gcheckbox)
export(gcheckboxgroup)
export(gcombobox)
export(gconfirm)
export(gdf)
export(gdfnotebook)
export(gdroplist)
export(gedit)
export(getBlock)
export(getStockIconByName)
export(getStockIcons)
export(getToolkitWidget)
export(getTopLevel)
export(getWidget)
export(getWithDefault)
export(gexpandgroup)
export(gfile)
export(gfilebrowse)
export(gfilter)
export(gformlayout)
export(gframe)
export(ggraphics)
export(ggraphicsnotebook)
export(ggroup)
export(ghtml)
export(gimage)
export(ginput)
export(glabel)
export(glayout)
export(gmenu)
export(gmessage)
export(gnotebook)
export(gpanedgroup)
export(gprogressbar)
export(gradio)
export(gseparator)
export(gslider)
export(gspinbutton)
export(gstackwidget)
export(gstatusbar)
export(gtable)
export(gtext)
export(gtimer)
export(gtoolbar)
export(gtoolkit)
export(gtree)
export(guiToolkit)
export(gvarbrowser)
export(gvbox)
export(gwindow)
export(insert)
export(isExtant)
export(is_MacOSX)
export(is_Windows)
export(is_empty)
export(redo)
export(removeHandler)
export(short_summary)
export(size)
export(stockIconFromClass)
export(stockIconFromObject)
export(svalue)
export(tag)
export(tooltip)
export(unblockHandler)
export(unblockHandlers)
export(undo)
export(visible)
exportClasses(BasicToolkitInterface)
exportClasses(Command)
exportClasses(CommandList)
exportClasses(CommandStack)
exportClasses(GWidgets2Icons)
exportClasses(Observable)
exportClasses(WSWatcherModel)
exportClasses(guiWidgetsToolkit)
import(digest)
import(methods)

S3method(.addStockIcons,default)
S3method(.getStockIconByName,default)
S3method(.getStockIcons,default)
S3method(.ggraphicsnotebook, default)
S3method(.stockIconFromClass,default)
S3method(.stockIconFromObject,default)
S3method(addHandlerChanged,GGraphics)
