Run here then copy .R and .pdf into ../doc directory.

This way we don't need to suggest gWidgets2RGtk2 when building gWidgets2


library(knitr)
purl("gWidgets2.Rnw")
knit2pdf("gWidgets2.Rnw")
system("cp gWidgets2.R gWidgets2.pdf ../doc/")
unlink(paste("gWidgets2", c("log", "out", "tex", "aux"), sep="."))

